@@ -9,9 +9,9 @@ use warnings;
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-12'; # DATE
+our $DATE = '2023-02-14'; # DATE
 our $DIST = 'Number-Format-Metric'; # DIST
-our $VERSION = '0.601'; # VERSION
+our $VERSION = '0.602'; # VERSION
 
 our @EXPORT_OK = qw(
                        format_metric
@@ -77,16 +77,18 @@ Number::Format::Metric - Format number with metric prefix
 
 =head1 VERSION
 
-This document describes version 0.601 of Number::Format::Metric (from Perl distribution Number-Format-Metric), released on 2023-02-12.
+This document describes version 0.602 of Number::Format::Metric (from Perl distribution Number-Format-Metric), released on 2023-02-14.
 
 =head1 SYNOPSIS
 
  use Number::Format::Metric qw(format_metric);
 
- format_metric(14     , {base=>10});               # => "14"
- format_metric(12000  , {base=> 2, precision=>1}); # => "11.7k"
- format_metric(12000  , {base=>10, precision=>1}); # => "11.7ki"
- format_metric(-0.0017, {base=>10});               # => "1.7m"
+ format_metric(14     , {base=>10});               # => "14.0"
+ format_metric(14     , {base=>10, precision=>0}); # => "14"
+ format_metric(12001  , {base=> 2, precision=>1}); # => "11.7k"
+ format_metric(12001  , {base=>10, precision=>3}); # => "12.001ki"
+ format_metric(-0.0017, {base=>10});               # => "-1.7m"
+ format_metric(1.26e6 , {base=>10});               # => "1.3Mi"
 
 =head1 FUNCTIONS
 
